/*
 * 商户服务费缴纳记录
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Data;
using MySystem.MainModels;
using Library;
using LitJson;

namespace MySystem.Service.Main
{
    public class MerchantDepositOrderService
    {
        static string _conn = ConfigurationManager.AppSettings["SqlConnStr"].ToString();

        /// <summary>
        /// 查询列表
        /// </summary>
        /// <param name="fields">查询条件(单个字段)</param>
        /// <param name="condition">查询条件(sql语句)</param>
        /// <param name="page">页码</param>
        /// <param name="limit">每页条数</param>
        /// <returns></returns>
        public List<Dictionary<string, object>> List(List<FieldItem> fields, string condition, int page = 1, int limit = 30, string orderby = "Id desc")
        {
            Dictionary<string, object> obj = new DbService(AppConfig.Base.mainTables, _conn).IndexData("MerchantDepositOrder", fields, orderby, "0", page, limit, condition);
            List<Dictionary<string, object>> diclist = obj["data"] as List<Dictionary<string, object>>;
            return diclist;
        }

        /// <summary>
        /// 通过商户Id查询一条记录
        /// </summary>
        /// <param name="MerchantId">商户Id</param>
        /// <returns></returns>
        public MerchantDepositOrder QueryByMerchantId(int MerchantId)
        {
            WebCMSEntities db = new WebCMSEntities();
            MerchantDepositOrder editData = db.MerchantDepositOrder.FirstOrDefault(m => m.Status > 0 && m.MerchantId == MerchantId) ?? new MerchantDepositOrder();
            db.Dispose();
            return editData;
        }

        /// <summary>
        /// 通过Id查询一条记录
        /// </summary>
        /// <param name="Id">主键Id</param>
        /// <returns></returns>
        public MerchantDepositOrder QueryById(int Id)
        {
            WebCMSEntities db = new WebCMSEntities();
            MerchantDepositOrder editData = db.MerchantDepositOrder.FirstOrDefault(m =>  m.Id == Id) ?? new MerchantDepositOrder();
            db.Dispose();
            return editData;
        }

        public Dictionary<string, string> Sum(string field, string condition)
        {
            Dictionary<string, string> result = new Dictionary<string, string>();
            string sumString = "";
            string[] fieldlist = field.Split(',');
            foreach(string f in fieldlist)
            {
                sumString += "sum(" + f + ") " + f + ",";
            }
            sumString = sumString.TrimEnd(',');
            DataTable dt = CustomerSqlConn.dtable("select " + sumString + " from MerchantDepositOrder where 1=1" + condition, _conn);
            if(dt.Rows.Count > 0)
            {
                foreach(string f in fieldlist)
                {
                    result.Add(f, function.CheckNum(dt.Rows[0][f].ToString()));
                }
            }
            return result;
        }

        // /// <summary>
        // /// 查询记录数
        // /// </summary>
        // /// <param name="Id">主键Id</param>
        // /// <returns></returns>
        // public static int Count(string condition = "", string field = "Id")
        // {
        //     int result = 0;
        //     Dictionary<string, object> obj = new DbService(AppConfig.Base.mainTables, _conn).Query("count(" + field + ") " + field + "", "MerchantDepositOrder", condition);
        //     if (obj.Keys.Count > 0)
        //     {
        //         result = int.Parse(function.CheckInt(obj[field].ToString()));
        //     }
        //     return result;
        // }

        // /// <summary>
        // /// 查询是否存在
        // /// </summary>
        // /// <param name="Id">主键Id</param>
        // /// <returns></returns>
        // public static bool Exist(string condition)
        // {
        //     Dictionary<string, object> obj = new DbService(AppConfig.Base.mainTables, _conn).Query("1", "MerchantDepositOrder", condition);
        //     if (obj.Keys.Count > 0)
        //     {
        //         return true;
        //     }
        //     return false;
        // }

        /// <summary>
        /// 添加数据
        /// </summary>
        /// <param name="Fields">要设置的字段</param>
        /// <returns></returns>
        public static AppResultJson Add(Dictionary<string, object> fields, bool check = true)
        {
            if (check)
            {
                if (string.IsNullOrEmpty(fields["MerchantId"].ToString()))
                {
                    return new AppResultJson() { Status = "-1", Info = "请填写商户Id" };
                }
                if (!function.IsInt(fields["MerchantId"].ToString()))
                {
                    return new AppResultJson() { Status = "-1", Info = "请填写正确的商户Id" };
                }
                if (string.IsNullOrEmpty(fields["UserId"].ToString()))
                {
                    return new AppResultJson() { Status = "-1", Info = "请填写创客Id" };
                }
                if (!function.IsInt(fields["UserId"].ToString()))
                {
                    return new AppResultJson() { Status = "-1", Info = "请填写正确的创客Id" };
                }

            }
            int Id = new DbService(AppConfig.Base.mainTables, _conn).Add("MerchantDepositOrder", fields, 0);
            return new AppResultJson() { Status = "1", Data = Id };
        }

        /// <summary>
        /// 修改数据
        /// </summary>
        /// <param name="Fields">要设置的字段</param>
        /// <param name="Id">主键Id</param>
        public static AppResultJson Edit(Dictionary<string, object> fields, int Id, bool check = true)
        {
            if (check)
            {
                if (string.IsNullOrEmpty(fields["MerchantId"].ToString()))
                {
                    return new AppResultJson() { Status = "-1", Info = "请填写商户Id" };
                }
                if (!function.IsInt(fields["MerchantId"].ToString()))
                {
                    return new AppResultJson() { Status = "-1", Info = "请填写正确的商户Id" };
                }
                if (string.IsNullOrEmpty(fields["UserId"].ToString()))
                {
                    return new AppResultJson() { Status = "-1", Info = "请填写创客Id" };
                }
                if (!function.IsInt(fields["UserId"].ToString()))
                {
                    return new AppResultJson() { Status = "-1", Info = "请填写正确的创客Id" };
                }

            }
            new DbService(AppConfig.Base.mainTables, _conn).Edit("MerchantDepositOrder", fields, Id);
            return new AppResultJson() { Status = "1", Data = Id };
        }

        /// <summary>
        /// 逻辑删除
        /// </summary>
        /// <param name="Id">主键Id</param>
        public static void Remove(int Id)
        {
            Dictionary<string, object> fields = new Dictionary<string, object>();
            fields.Add("Status", -1);
            new DbService(AppConfig.Base.mainTables, _conn).Edit("MerchantDepositOrder", fields, Id);
        }

        /// <summary>
        /// 删除数据
        /// </summary>
        /// <param name="Id">主键Id</param>
        public static void Delete(int Id)
        {
            new DbService(AppConfig.Base.mainTables, _conn).Delete("MerchantDepositOrder", Id);
        }

        /// <summary>
        /// 排序
        /// </summary>
        /// <param name="Id">主键Id</param>
        /// <param name="Sort">排序序号</param>
        public static void Sort(int Id, int Sort)
        {
            new DbService(AppConfig.Base.mainTables, _conn).Sort("MerchantDepositOrder", Sort, Id);
        }

        /// <summary>
        /// 导入数据
        /// </summary>
        /// <param name="ExcelData">json数据</param>
        public static void Import(string ExcelData)
        {
            // WebCMSEntities db = new WebCMSEntities();
            // JsonData list = JsonMapper.ToObject(ExcelData);
            // for (int i = 1; i < list.Count;i++ )
            // {
            //     JsonData dr = list[i];

            //     db.MerchantDepositOrder.Add(new MerchantDepositOrder()
            //     {
            //         CreateDate = DateTime.Now,
            //         UpdateDate = DateTime.Now,

            //     });
            //     db.SaveChanges();
            // }
            // db.Dispose();
        }

        /// <summary>
        /// 导出excel表格
        /// </summary>
        /// <param name="fields">查询条件(单个字段)</param>
        /// <param name="condition">查询条件(sql语句)</param>
        /// <returns></returns>
        // public static void ExportExcel(List<RelationData> relationData, string condition)
        // {

        // }
    }
}